@@ -45,10 +45,26 @@ async def openai_example():
     extractions.save(document.name, save_format=docviz.SaveFormat.JSON)
 
 
+async def streaming_example():
+    document = docviz.Document(r"examples\data\2507.21509v1.pdf")
+
+    async for page_result in document.extract_streaming(
+        extraction_config=docviz.ExtractionConfig(page_limit=3),
+        includes=[docviz.ExtractionType.TEXT],
+    ):
+        page_result.save(
+            document.name + f"_page{page_result.page_number}",
+            save_format=docviz.SaveFormat.JSON,
+        )
+        if page_result.page_number >= 3:
+            break
+
+
 async def main():
     # await simple_example()
-    await url_example()
+    # await url_example()
     # await openai_example()
+    await streaming_example()
 
 
 if __name__ == "__main__":
